==> haskell-optparse-applicative-0.13.2.0-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-optparse-applicative.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: optparse-applicative
version: 0.13.2.0
id: optparse-applicative-0.13.2.0-403Af4vaGHEIyn0ZdeZhZL
key: optparse-applicative-0.13.2.0-403Af4vaGHEIyn0ZdeZhZL
license: BSD3
copyright: (c) 2012-2017 Paolo Capriotti <paolo@capriotti.io>
maintainer: paolo@capriotti.io
homepage: https://github.com/pcapriotti/optparse-applicative
synopsis: Utilities and combinators for parsing command line options
description:
    optparse-applicative is a haskell library for parsing options
    on the command line, providing a powerful applicative interface
    for composing these options.
    .
    optparse-applicative takes care of reading and validating the
    arguments passed to the command line, handling and reporting
    errors, generating a usage line, a comprehensive help screen,
    and enabling context-sensitive bash completions.
    .
    See the included README for detailed instructions and examples,
    which is also available on github
    <https://github.com/pcapriotti/optparse-applicative>.
category: System
author: Paolo Capriotti, Huw Campbell
exposed: True
exposed-modules:
    Options.Applicative Options.Applicative.Arrows
    Options.Applicative.BashCompletion Options.Applicative.Builder
    Options.Applicative.Builder.Completer
    Options.Applicative.Builder.Internal Options.Applicative.Common
    Options.Applicative.Extra Options.Applicative.Help
    Options.Applicative.Help.Pretty Options.Applicative.Help.Chunk
    Options.Applicative.Help.Core Options.Applicative.Help.Types
    Options.Applicative.Types Options.Applicative.Internal
abi: 1960a2c471fb50d57a8bcbacd5b0136f
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/optparse-applicative-0.13.2.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/optparse-applicative-0.13.2.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/optparse-applicative-0.13.2.0
hs-libraries: HSoptparse-applicative-0.13.2.0-403Af4vaGHEIyn0ZdeZhZL
depends:
    ansi-wl-pprint-0.6.7.3-BxXaXM4de7bF6SGXMvMtbC base-4.9.0.0
    process-1.4.2.0 transformers-0.5.2.0
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
haddock-interfaces: /usr/share/doc/haskell-optparse-applicative/html/optparse-applicative.haddock
haddock-html: /usr/share/doc/haskell-optparse-applicative/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-optparse-applicative-0.13.2.0-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-optparse-applicative.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: optparse-applicative
version: 0.13.2.0
id: optparse-applicative-0.13.2.0-7Y0agREbHDlBXdHE81XeQP
key: optparse-applicative-0.13.2.0-7Y0agREbHDlBXdHE81XeQP
license: BSD3
copyright: (c) 2012-2017 Paolo Capriotti <paolo@capriotti.io>
maintainer: paolo@capriotti.io
homepage: https://github.com/pcapriotti/optparse-applicative
synopsis: Utilities and combinators for parsing command line options
description:
    optparse-applicative is a haskell library for parsing options
    on the command line, providing a powerful applicative interface
    for composing these options.
    .
    optparse-applicative takes care of reading and validating the
    arguments passed to the command line, handling and reporting
    errors, generating a usage line, a comprehensive help screen,
    and enabling context-sensitive bash completions.
    .
    See the included README for detailed instructions and examples,
    which is also available on github
    <https://github.com/pcapriotti/optparse-applicative>.
category: System
author: Paolo Capriotti, Huw Campbell
exposed: True
exposed-modules:
    Options.Applicative Options.Applicative.Arrows
    Options.Applicative.BashCompletion Options.Applicative.Builder
    Options.Applicative.Builder.Completer
    Options.Applicative.Builder.Internal Options.Applicative.Common
    Options.Applicative.Extra Options.Applicative.Help
    Options.Applicative.Help.Pretty Options.Applicative.Help.Chunk
    Options.Applicative.Help.Core Options.Applicative.Help.Types
    Options.Applicative.Types Options.Applicative.Internal
abi: a6b4a9ccfe27ef804dc70e328e617f24
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/optparse-applicative-0.13.2.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/optparse-applicative-0.13.2.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/optparse-applicative-0.13.2.0
hs-libraries: HSoptparse-applicative-0.13.2.0-7Y0agREbHDlBXdHE81XeQP
depends:
    ansi-wl-pprint-0.6.7.3-6GCcsFDbx2V8PibFjHfpG5 base-4.9.0.0
    process-1.4.2.0 transformers-0.5.2.0
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
haddock-interfaces: /usr/share/doc/haskell-optparse-applicative/html/optparse-applicative.haddock
haddock-html: /usr/share/doc/haskell-optparse-applicative/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
